
Languages
==============

The following fold out menus contain all of the languages included in Asent.
The :octicon:`beaker;1em;sd-text-info` indicate that the language lexicon is
autogenerated and therefore experimental.



.. dropdown:: English
   :open:

   .. tab-set::


      .. tab-item:: Default

         :bdg-info-line:`License: MIT`

         The lexicons contain a list of rated words for English along with intensifiers,
         contrastive conjugations and negations. The words are rated by 
         `Hutto and Gilbert, (2014) <https://ojs.aaai.org/index.php/ICWSM/article/view/14550>`__.

         The lexicons contain a total of 7504 rated words, 59 negations, 84 intensifiers,
         and 1 contrastive conjugations.

         You can load the English lexicons using:

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("lexicon_en_v1") 
            negations = lexicons.get("negations_en_v1")
            intensifiers = lexicons.get("intensifiers_en_v1")
            cconj = lexicons.get("contrastive_conj_en_v1")


      .. tab-item:: Chen & Skiena (2014)
      
         :bdg-info-line:`License: GNU 3.0`

         This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
         using by propagation using a knowledge graph - a graphical representation of
         real-world entities and the
         links between them. The general intuition is that words which are closely
         linked on a knowledge graph probably have similar sentiment polarities. For
         this project, sentiments were generated based on English sentiment lexicons.

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("lexicon_en_chen_skiena_2014_v1.txt") 


.. dropdown:: Danish


   .. tab-set::

      .. tab-item:: Default

         :bdg-info-line:`License: Apache 2.0`

         The Danish lexical resources contain a list of rated words derived from `Afinn <https://github.com/fnielsen/afinn>`__.
         The lexicon also include intensifier, contrastive conjugations
         and negations. It includes a total of 6593 rated lemmas along with intensifier, contrastive conjugations
         and negations.

         You can load the Danish lexicons using:

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("lexicon_da_afinn_v1")
            negations = lexicons.get("negations_da_v1")
            intensifiers = lexicons.get("intensifiers_da_v1")
            cconj = lexicons.get("contrastive_conj_da_v1")

      .. tab-item:: Sentida

         :bdg-info-line:`License: CC BY-NC 3.0`

         Beyond the default lexicon Asent also include a series of words rated in context by
         `Dalsgaard, Lauridsen and  Svendsen (2019) <https://tidsskrift.dk/lwo/article/view/115711>`__. Which have been lemmatized using DaCy 
         `(Enevoldsen et al., 2021) <https://github.com/centre-for-humanities-computing/DaCy>`__. This dictionary:
         
         .. code-block:: python

            rated_words = lexicons.get("lexicon_da_sentida_lemma_v1") 


      .. tab-item:: Chen & Skiena (2014)
      
         :bdg-info-line:`License: GNU 3.0`

         This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
         using by propagation using a knowledge graph - a graphical representation of
         real-world entities and the
         links between them. The general intuition is that words which are closely
         linked on a knowledge graph probably have similar sentiment polarities. For
         this project, sentiments were generated based on English sentiment lexicons.

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("lexicon_da_chen_skiena_2014_v1.txt") 



.. dropdown:: Norwegian Bokmål

   .. tab-set::

      .. tab-item:: Default

         :bdg-info-line:`License: Apache 2.0`

         The lexicons contain a list of rated words for Norwegian. The words are rated in context by Finn
         A. Nielsen as a part of his package `afinn <https://github.com/olavski/afinn/blob/master/afinn/data/AFINN-no-165.txt>`__.
         The contrastive conjugations, negations and intensifiers have been added by `Center for Humanities Computing Aarhus <https://chcaa.io>`__.

         The lexicon includes a total of 3214 rated words along with intensifier, contrastive conjugations and negations.

         You can load the Norwegian lexicons using:

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("lexicon_no_v1") 
            negations = lexicons.get("negations_no_v1")
            intensifiers = lexicons.get("intensifiers_no_v1")
            cconj = lexicons.get("contrastive_conj_no_v1")

      .. tab-item:: Chen & Skiena (2014)
      
         :bdg-info-line:`License: GNU 3.0`

         This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
         using by propagation using a knowledge graph - a graphical representation of
         real-world entities and the
         links between them. The general intuition is that words which are closely
         linked on a knowledge graph probably have similar sentiment polarities. For
         this project, sentiments were generated based on English sentiment lexicons.

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("lexicon_no_chen_skiena_2014_v1.txt") 



.. dropdown:: Swedish

   .. tab-set::

      .. tab-item:: Default

         :bdg-info-line:`License: MIT`

         The default lexicons is the same as the one used by the Swedish Vader, (`vaderSentiment-swedish <https://pypi.org/project/vaderSentiment-swedish/>`__)
         available on PyPI. 

         The lexicon includes a total of 5501 rated orthographic words as well as with intensifier, contrastive conjugations and negations.

         You can load the Swedish lexicons using:

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("lexicon_se_v1") 
            negations = lexicons.get("negations_se_v1")
            intensifiers = lexicons.get("intensifiers_se_v1")

      .. tab-item:: Chen & Skiena (2014)
      
         :bdg-info-line:`License: GNU 3.0`

         This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
         using by propagation using a knowledge graph - a graphical representation of
         real-world entities and the
         links between them. The general intuition is that words which are closely
         linked on a knowledge graph probably have similar sentiment polarities. For
         this project, sentiments were generated based on English sentiment lexicons.

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("lexicon_se_chen_skiena_2014_v1.txt") 




.. dropdown:: Emoji

   .. tab-set::

      .. tab-item:: Default

         :bdg-info-line:`License: MIT`

         The rating of emojis is created by applying Vader `(Hutto and Gilbert, 2014) <https://ojs.aaai.org/index.php/ICWSM/article/view/14550>`__ to the description of the emojis. 
         Afterwards, the scores are normalized to be between -5 and 5. 

         It contains a total of 3570 rated emojis of which 391 of them has a non-zero rating.

         You can load the Emoji lexicon using:

         .. code-block:: python

            from asent import lexicons
            rated_words = lexicons.get("emoji_v1") 




.. dropdown:: Experimental
   :icon: beaker


      These sentiment lexicons were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
      using by propagation using a knowledge graph - a graphical representation of
      real-world entities and the
      links between them. The general intuition is that words which are closely
      linked on a knowledge graph probably have similar sentiment polarities. For
      this project, sentiments were generated based on English sentiment lexicons.

   .. dropdown:: Afrikaans
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_af_chen_skiena_2014_v1.txt") 



   .. dropdown:: Albanian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_sq_chen_skiena_2014_v1.txt") 



   .. dropdown:: Arabic
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ar_chen_skiena_2014_v1.txt") 



   .. dropdown:: Arabic
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ar_chen_skiena_2014_v1.txt") 




   .. dropdown:: Aragonese
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_an_chen_skiena_2014_v1.txt") 



   .. dropdown:: Aragonese
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_an_chen_skiena_2014_v1.txt") 


   .. dropdown:: Armenian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_hy_chen_skiena_2014_v1.txt") 



   .. dropdown:: Azerbaijani
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_az_chen_skiena_2014_v1.txt") 




   .. dropdown:: Basque
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_eu_chen_skiena_2014_v1.txt") 




   .. dropdown:: Belarusian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_be_chen_skiena_2014_v1.txt") 



   .. dropdown:: Bulgarian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_bg_chen_skiena_2014_v1.txt") 




   .. dropdown:: Bengali
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_bn_chen_skiena_2014_v1.txt") 



   .. dropdown:: Breton
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_br_chen_skiena_2014_v1.txt") 




   .. dropdown:: Bosnian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_bs_chen_skiena_2014_v1.txt") 




   .. dropdown:: Catalan
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ca_chen_skiena_2014_v1.txt") 


   .. dropdown:: Czech
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_cs_chen_skiena_2014_v1.txt") 


   .. dropdown:: Chinese
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_zh_chen_skiena_2014_v1.txt") 



   .. dropdown:: Croatian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_cr_chen_skiena_2014_v1.txt") 




   .. dropdown:: Czech
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_cs_chen_skiena_2014_v1.txt") 





   .. dropdown:: Dutch
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_nl_chen_skiena_2014_v1.txt") 





   .. dropdown:: Estonian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_et_chen_skiena_2014_v1.txt") 




   .. dropdown:: Esperanto
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_eo_chen_skiena_2014_v1.txt") 





   .. dropdown:: Faroese
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_fo_chen_skiena_2014_v1.txt") 





   .. dropdown:: Finnish
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_fi_chen_skiena_2014_v1.txt") 




   .. dropdown:: French
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_fr_chen_skiena_2014_v1.txt") 



   .. dropdown:: Galician
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_gl_chen_skiena_2014_v1.txt") 




   .. dropdown:: Georgian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ka_chen_skiena_2014_v1.txt") 


   .. dropdown:: German
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_de_chen_skiena_2014_v1.txt") 



   .. dropdown:: German
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_de_chen_skiena_2014_v1.txt") 



   .. dropdown:: Gujarati
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_gu_chen_skiena_2014_v1.txt") 


   .. dropdown:: Greek, modern
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_el_chen_skiena_2014_v1.txt") 



   .. dropdown:: Haitian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ht_chen_skiena_2014_v1.txt") 




   .. dropdown:: Hungarian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_hu_chen_skiena_2014_v1.txt") 




   .. dropdown:: Hebrew, modern
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_gu_chen_skiena_2014_v1.txt") 




   .. dropdown:: Hindi
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_hi_chen_skiena_2014_v1.txt") 




   .. dropdown:: Icelandic
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_is_chen_skiena_2014_v1.txt") 





   .. dropdown:: Italian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_it_chen_skiena_2014_v1.txt") 






   .. dropdown:: Ido
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_io_chen_skiena_2014_v1.txt") 




   .. dropdown:: Indonesian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_id_chen_skiena_2014_v1.txt") 





   .. dropdown:: Interlingua
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ia_chen_skiena_2014_v1.txt") 







   .. dropdown:: Irish
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ga_chen_skiena_2014_v1.txt") 



   .. dropdown:: Kannada
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_kn_chen_skiena_2014_v1.txt") 




   .. dropdown:: Khmer
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_km_chen_skiena_2014_v1.txt") 



   .. dropdown:: Kirghiz, Kyrgyz
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ky_chen_skiena_2014_v1.txt") 



   .. dropdown:: Korean
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ko_chen_skiena_2014_v1.txt") 


   .. dropdown:: Kurdish
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ku_chen_skiena_2014_v1.txt") 



   .. dropdown:: Latin
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_la_chen_skiena_2014_v1.txt") 



   .. dropdown:: Latvian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_lv_chen_skiena_2014_v1.txt") 



   .. dropdown:: Lithuanian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_lt_chen_skiena_2014_v1.txt") 



   .. dropdown:: Luxembourgish
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_lb_chen_skiena_2014_v1.txt") 




   .. dropdown:: Luxembourgish
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_lb_chen_skiena_2014_v1.txt") 


   .. dropdown:: Macedonian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_mk_chen_skiena_2014_v1.txt") 




   .. dropdown:: Macedonian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_mk_chen_skiena_2014_v1.txt") 



   .. dropdown:: Malay
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ms_chen_skiena_2014_v1.txt") 




   .. dropdown:: Malay
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ms_chen_skiena_2014_v1.txt") 


   .. dropdown:: Maltese
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_mt_chen_skiena_2014_v1.txt") 




   .. dropdown:: Marathi
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_mr_chen_skiena_2014_v1.txt") 


   .. dropdown:: Norwegian Nynorsk
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_nn_chen_skiena_2014_v1.txt") 



   .. dropdown:: Persian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_fa_chen_skiena_2014_v1.txt") 




   .. dropdown:: Polish
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_pl_chen_skiena_2014_v1.txt") 



   .. dropdown:: Portuguese
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_pt_chen_skiena_2014_v1.txt") 



   .. dropdown:: Romanian, Moldavian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ro_chen_skiena_2014_v1.txt") 



   .. dropdown:: Romansh
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_rm_chen_skiena_2014_v1.txt") 




   .. dropdown:: Romansh
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_rm_chen_skiena_2014_v1.txt") 



   .. dropdown:: Russian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ru_chen_skiena_2014_v1.txt") 





   .. dropdown:: Scottish Gaelic
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_gd_chen_skiena_2014_v1.txt") 




   .. dropdown:: Scottish Gaelic
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_gd_chen_skiena_2014_v1.txt") 

   .. dropdown:: Serbian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_sr_chen_skiena_2014_v1.txt") 



   .. dropdown:: Slovak
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_sk_chen_skiena_2014_v1.txt") 


   .. dropdown:: Slovene
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_sl_chen_skiena_2014_v1.txt") 


   .. dropdown:: Spanish, Castilian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_es_chen_skiena_2014_v1.txt") 



   .. dropdown:: Swahili
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_sw_chen_skiena_2014_v1.txt") 


   .. dropdown:: Tamil
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ta_chen_skiena_2014_v1.txt") 



   .. dropdown:: Tagalog
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_tl_chen_skiena_2014_v1.txt") 



   .. dropdown:: Telugu
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_te_chen_skiena_2014_v1.txt") 


   .. dropdown:: Thai
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_th_chen_skiena_2014_v1.txt") 


   .. dropdown:: Turkmen
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_tk_chen_skiena_2014_v1.txt") 


   .. dropdown:: Turkish
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_tr_chen_skiena_2014_v1.txt") 



   .. dropdown:: Ukrainian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_uk_chen_skiena_2014_v1.txt") 




   .. dropdown:: Urdu
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_ur_chen_skiena_2014_v1.txt") 



   .. dropdown:: Uzbek
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_uz_chen_skiena_2014_v1.txt") 





   .. dropdown:: Vietnamese
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_vi_chen_skiena_2014_v1.txt") 



   .. dropdown:: Volapük
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_vo_chen_skiena_2014_v1.txt") 




   .. dropdown:: Walloon
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_wa_chen_skiena_2014_v1.txt") 




   .. dropdown:: Welsh
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_cy_chen_skiena_2014_v1.txt") 



   .. dropdown:: Western Frisian
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_fy_chen_skiena_2014_v1.txt") 


   .. dropdown:: Yiddish
      :icon: beaker

      .. tab-set::

         .. tab-item:: Default
         
            :bdg-info-line:`License: GNU 3.0`

            This sentiment lexicon were generated by `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__
            using by propagation using a knowledge graph - a graphical representation of
            real-world entities and the
            links between them. The general intuition is that words which are closely
            linked on a knowledge graph probably have similar sentiment polarities. For
            this project, sentiments were generated based on English sentiment lexicons.

            .. code-block:: python

               from asent import lexicons
               rated_words = lexicons.get("lexicon_yi_chen_skiena_2014_v1.txt") 
